@@ -228,8 +228,8 @@ def do_create(cs, args):
            help='List containers according to their hostname')
 @utils.arg('--auto-remove',
            metavar='<auto-remove>',
-           help='List container according to whether they are'
-                'auto-removed on existing')
+           help='List containers according to whether they are '
+                'auto-removed on exiting')
 def do_list(cs, args):
     """Print a list of available containers."""
     opts = {}
@@ -846,17 +846,25 @@ def do_add_security_group(cs, args):
               "failed: %(e)s" % {'container': args.container, 'e': e})
 
 
+@utils.exclusive_arg(
+    'detach_network_port',
+    '--network',
+    metavar='<network>',
+    help='The neutron network that container will detach from.')
+@utils.exclusive_arg(
+    'detach_network_port',
+    '--port',
+    metavar='<port>',
+    help='The neutron port that container will detach from.')
 @utils.arg('container',
            metavar='<container>',
            help='ID or name of the container to detach the network.')
-@utils.arg('network',
-           metavar='<network>',
-           help='The neutron network that container will detach from.')
 def do_network_detach(cs, args):
     """Detach a network from the container."""
     opts = {}
     opts['container'] = args.container
     opts['network'] = args.network
+    opts['port'] = args.port
     opts = zun_utils.remove_null_parms(**opts)
     try:
         cs.containers.network_detach(**opts)
@@ -905,10 +913,7 @@ def do_network_list(cs, args):
     opts['container'] = args.container
     opts = zun_utils.remove_null_parms(**opts)
     networks = cs.containers.network_list(**opts)
-    columns = ('net_id', 'subnet_id', 'port_id', 'version', 'ip_address')
-    utils.print_list(networks, columns,
-                     {'versions': zun_utils.print_list_field('versions')},
-                     sortby_index=None)
+    zun_utils.list_container_networks(networks)
 
 
 @utils.arg('container',
